@@ -18,6 +18,7 @@ RequestSchema = schema.dict({
     "params": ParamListSchema(),
     "headers": HeaderListSchema(),
     "body": schema.any,
+    "raw": schema.bytes,
 })
 
 
@@ -33,3 +34,8 @@ class HistoryRequestSchema(GenericTypeAliasSchema[HistoryRequestProps]):
             return cast(ReturnType, visitor.visit_jj_history_request(self, **kwargs))
         except AttributeError:
             return visitor.visit_type_alias(self, **kwargs)
+
+    def __add__(self, /, other: DictSchema) -> "HistoryRequestSchema":
+        assert isinstance(other, DictSchema)
+        merged = self.props.type + other
+        return self.__class__(self.props.update(type=merged))
