@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Any, Optional
 
 from jj.mock import HistoryResponse
 from multidict import CIMultiDict, CIMultiDictProxy
@@ -10,7 +10,8 @@ def make_history_response(*,
                           status: int = 200,
                           reason: str = "OK",
                           headers: Optional[CIMultiDict] = None,
-                          body: bytes = b"") -> HistoryResponse:
+                          body: Any = b"",
+                          raw: bytes = b"") -> HistoryResponse:
     if headers is None:
         headers = CIMultiDict()
     return HistoryResponse(
@@ -18,4 +19,5 @@ def make_history_response(*,
         reason=reason,
         headers=CIMultiDictProxy(headers),
         body=body,
+        raw=raw,
     )
